/// <reference types="node" />
import Context from './Context';
import { ConsoleMessageType, Page, Viewport } from 'puppeteer';
import { IExpectation } from './Expects';
export declare type IPageInclude = {
    url: string;
    method: string;
    resourceType: string;
    content: Buffer;
    headers: Record<string, string>;
};
export declare type ISnapshot = {
    type: string;
    html: any;
    version: number;
    url: any;
    viewport: Viewport | null;
    includes?: IPageInclude[];
};
export declare type ICommandError = {
    type: string;
    specific?: string;
    error?: Error;
    expectation?: IExpectation;
    time: number;
};
export declare type ICommand = {
    id: string;
    type: 'command';
    snapshots: {
        before: ISnapshot | undefined;
        after: ISnapshot | undefined;
    };
    errors: ICommandError[];
    context: {};
    func: string;
    args: string[];
    on: {
        type: string;
        path: [[string, number][] | string][];
    };
    time: {
        started: number;
        finished?: number;
    };
};
declare type ILogLocation = {
    url?: string;
    lineNumber?: number;
    columnNumber?: number;
};
declare type ILog = {
    type: 'log';
    context: {};
    time: number;
    messageType: ConsoleMessageType;
    args: any[];
    location: ILogLocation;
    text: string;
    stackTrace: ILogLocation[];
};
declare type IResponse = {
    type: 'response';
    context: {};
    time: number;
    isNavigationRequest: boolean;
    url: string;
    resourceType: string;
    method: string;
    headers: {
        [key: string]: string;
    };
    content: Buffer;
};
declare class SnapshotHandler {
    private snapshots;
    private commands;
    private logs;
    private responses;
    log(...msg: any[]): void;
    getSnapshots(): {};
    getCommands(): ICommand[];
    addLog(log: ILog): void;
    addResponse(response: IResponse): void;
    createBefore(context: Context, page: Page, command: ICommand | undefined): Promise<void>;
    createAfter(context: Context, page: Page, command: ICommand | undefined): Promise<void>;
    error(param: Context, page: Page, command: ICommand | undefined, error: ICommandError): void;
    broadcast(object: any): void;
    makeSnapshot(page: Page): Promise<ISnapshot | undefined>;
    getLogs(): ILog[];
    getResponses(): IResponse[];
}
declare const Snapshots: SnapshotHandler;
export default Snapshots;
